@@ -957,7 +957,3 @@ FOREIGN KEY (atom) REFERENCES data_atom(id),
 FOREIGN KEY (id_device) REFERENCES devices(id_device) ON DELETE CASCADE
 );
 
-CREATE TRIGGER delban_6_dcl
-BEFORE DELETE ON data_change_log
-FOR EACH ROW
-SIGNAL SQLSTATE '45000' SET MESSAGE_TEXT = 'Delete not allowed on simpletable';
